@@ -13,7 +13,7 @@
  * 
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
- * Public License as published bythe Free Software Foundation;
+ * Public License as published by the Free Software Foundation;
  * either version 2, or (at your option)
  * any later version.
  * 
@@ -24,14 +24,8 @@
  * 
  * ============================================================ */
 
-
 #define TILE_HEIGHT       64 
  
-// Imlib2 include.
-
-#define X_DISPLAY_MISSING 1
-#include <Imlib2.h>
-
 // C++ include.
 
 #include <cstring>
@@ -61,15 +55,13 @@
 #include <kiconloader.h>
 #include <kapplication.h>
 #include <kpopupmenu.h>
-#include <kimageeffect.h>
 #include <kprogress.h>
 #include <kdebug.h>
 #include <kstandarddirs.h>
 
 // Digikam includes.
 
-#include <digikam/imageiface.h>
-#include <digikam/imagepreviewwidget.h>
+#include <digikamheaders.h>
 
 // Local includes.
 
@@ -94,11 +86,11 @@ DespeckleDialog::DespeckleDialog(QWidget* parent)
     KAboutData* about = new KAboutData("digikamimageplugins",
                                        I18N_NOOP("Noise Reduction"), 
                                        digikamimageplugins_version,
-                                       I18N_NOOP("A despeckle image filter plugin for Digikam."),
+                                       I18N_NOOP("A despeckle image filter plugin for digiKam."),
                                        KAboutData::License_GPL,
                                        "(c) 2004, Gilles Caulier", 
                                        0,
-                                       "http://extragear.kde.org/apps/digikamimageplugins.php");
+                                       "http://extragear.kde.org/apps/digikamimageplugins");
     
     about->addAuthor("Gilles Caulier", I18N_NOOP("Author and maintainer"),
                      "caulier dot gilles at free.fr");
@@ -132,7 +124,8 @@ DespeckleDialog::DespeckleDialog(QWidget* parent)
     QString directory;
     KGlobal::dirs()->addResourceType("digikamimageplugins_banner_left", KGlobal::dirs()->kde_default("data") +
                                                                         "digikamimageplugins/data");
-    directory = KGlobal::dirs()->findResourceDir("digikamimageplugins_banner_left", "digikamimageplugins_banner_left.png");
+    directory = KGlobal::dirs()->findResourceDir("digikamimageplugins_banner_left",
+                                                 "digikamimageplugins_banner_left.png");
     
     pixmapLabelLeft->setPaletteBackgroundColor( QColor(201, 208, 255) );
     pixmapLabelLeft->setPixmap( QPixmap( directory + "digikamimageplugins_banner_left.png" ) );
@@ -143,7 +136,7 @@ DespeckleDialog::DespeckleDialog(QWidget* parent)
     QHBoxLayout *hlay1 = new QHBoxLayout(topLayout);
     
     m_imagePreviewWidget = new Digikam::ImagePreviewWidget(240, 160, 
-                                                           i18n("Noise Reduction Image Preview"),
+                                                           i18n("Preview"),
                                                            plainPage());
     hlay1->addWidget(m_imagePreviewWidget);
     
@@ -152,13 +145,13 @@ DespeckleDialog::DespeckleDialog(QWidget* parent)
     QHBoxLayout *hlay2 = new QHBoxLayout(topLayout);
     QLabel *label1 = new QLabel(i18n("Radius:"), plainPage());
     
-    m_radiusSlider = new QSlider(1, 20, 1, 1, Qt::Horizontal, plainPage(), "m_radiusSlider");
+    m_radiusSlider = new QSlider(1, 20, 1, 3, Qt::Horizontal, plainPage(), "m_radiusSlider");
     m_radiusSlider->setTickmarks(QSlider::Below);
     m_radiusSlider->setTickInterval(1);
     m_radiusSlider->setTracking ( false );
     
     m_radiusInput = new QSpinBox(1, 20, 1, plainPage(), "m_radiusInput");
-    
+    m_radiusInput->setValue(3);
     whatsThis = i18n("<p>A radius of 0 has no effect, "
                      "1 and above determine the blur matrix radius "
                      "that determines how much to blur the image.");
@@ -174,13 +167,13 @@ DespeckleDialog::DespeckleDialog(QWidget* parent)
     QHBoxLayout *hlay3 = new QHBoxLayout(topLayout);
     QLabel *label2 = new QLabel(i18n("Black level:"), plainPage());
     
-    m_blackLevelSlider = new QSlider(0, 255, 1, 1, Qt::Horizontal, plainPage(), "m_blackLevelSlider");
+    m_blackLevelSlider = new QSlider(0, 255, 1, 7, Qt::Horizontal, plainPage(), "m_blackLevelSlider");
     m_blackLevelSlider->setTickmarks(QSlider::Below);
     m_blackLevelSlider->setTickInterval(20);
     m_blackLevelSlider->setTracking ( false );  
     
     m_blackLevelInput = new QSpinBox(0, 255, 1, plainPage(), "m_blackLevelInput");
-    
+    m_blackLevelInput->setValue(7);    
     whatsThis = i18n("<p>This value controls adjust the black "
                      "levels used by the adaptive filter to "
                      "adjust the filter radius.");
@@ -196,13 +189,13 @@ DespeckleDialog::DespeckleDialog(QWidget* parent)
     QHBoxLayout *hlay4 = new QHBoxLayout(topLayout);
     QLabel *label3 = new QLabel(i18n("White level:"), plainPage());
     
-    m_whiteLevelSlider = new QSlider(0, 255, 1, 1, Qt::Horizontal, plainPage(), "m_whiteLevelSlider");
+    m_whiteLevelSlider = new QSlider(0, 255, 1, 248, Qt::Horizontal, plainPage(), "m_whiteLevelSlider");
     m_whiteLevelSlider->setTickmarks(QSlider::Below);
     m_whiteLevelSlider->setTickInterval(20);
     m_whiteLevelSlider->setTracking ( false );  
     
     m_whiteLevelInput = new QSpinBox(0, 255, 1, plainPage(), "m_whiteLevelInput");
-    
+    m_whiteLevelInput->setValue(248);    
     whatsThis = i18n("<p>This value controls adjust the white "
                      "levels used by the adaptive filter to "
                      "adjust the filter radius.");
@@ -234,6 +227,9 @@ DespeckleDialog::DespeckleDialog(QWidget* parent)
     QWhatsThis::add( m_progressBar, i18n("<p>This is the current percentage of the task completed.") );
     hlay6->addWidget(m_progressBar, 1);
     
+    adjustSize();
+    disableResize(); 
+    
     // -------------------------------------------------------------
     
     connect(m_imagePreviewWidget, SIGNAL(signalOriginalClipFocusChanged()),
@@ -265,12 +261,6 @@ DespeckleDialog::DespeckleDialog(QWidget* parent)
     
     connect(m_useRecursiveMethod, SIGNAL(toggled (bool)),
             this, SLOT(slotEffect()));             
-            
-    // -------------------------------------------------------------
-        
-    adjustSize();
-    disableResize();      
-    QTimer::singleShot(0, this, SLOT(slotUser1()));    // Reset all parameters to the default values.       
 }
 
 DespeckleDialog::~DespeckleDialog()
@@ -297,15 +287,12 @@ void DespeckleDialog::slotCancel()
 
 void DespeckleDialog::slotUser1()
 {
-    blockSignals(true);
-    disconnect(m_imagePreviewWidget, SIGNAL(signalOriginalClipFocusChanged()),
-               this, SLOT(slotEffect()));
-    disconnect(m_radiusInput, SIGNAL(valueChanged (int)),
-               this, SLOT(slotEffect()));
-    disconnect(m_blackLevelInput, SIGNAL(valueChanged (int)),
-               this, SLOT(slotEffect()));  
-    disconnect(m_whiteLevelInput, SIGNAL(valueChanged (int)),
-               this, SLOT(slotEffect()));                        
+    m_radiusInput->blockSignals(true);
+    m_radiusSlider->blockSignals(true);
+    m_blackLevelInput->blockSignals(true);
+    m_blackLevelSlider->blockSignals(true);
+    m_whiteLevelInput->blockSignals(true);
+    m_whiteLevelSlider->blockSignals(true);
             
     m_radiusInput->setValue(3);
     m_radiusSlider->setValue(3);
@@ -314,15 +301,12 @@ void DespeckleDialog::slotUser1()
     m_whiteLevelInput->setValue(248);
     m_whiteLevelSlider->setValue(248);
 
-    connect(m_imagePreviewWidget, SIGNAL(signalOriginalClipFocusChanged()),
-            this, SLOT(slotEffect()));    
-    connect(m_radiusInput, SIGNAL(valueChanged (int)),
-            this, SLOT(slotEffect()));
-    connect(m_blackLevelInput, SIGNAL(valueChanged (int)),
-            this, SLOT(slotEffect()));
-    connect(m_whiteLevelInput, SIGNAL(valueChanged (int)),
-            this, SLOT(slotEffect()));                          
-    blockSignals(false);
+    m_radiusInput->blockSignals(false);
+    m_radiusSlider->blockSignals(false);
+    m_blackLevelInput->blockSignals(false);
+    m_blackLevelSlider->blockSignals(false);
+    m_whiteLevelInput->blockSignals(false);
+    m_whiteLevelSlider->blockSignals(false);
     slotEffect();
 } 
 
@@ -353,6 +337,16 @@ void DespeckleDialog::slotEffect()
 
 void DespeckleDialog::slotOk()
 {
+    m_radiusInput->setEnabled(false);
+    m_radiusSlider->setEnabled(false);
+    m_blackLevelInput->setEnabled(false);
+    m_blackLevelSlider->setEnabled(false);
+    m_whiteLevelInput->setEnabled(false);
+    m_whiteLevelSlider->setEnabled(false);
+    m_useAdaptativeMethod->setEnabled(false);
+    m_useRecursiveMethod->setEnabled(false);
+    m_imagePreviewWidget->setEnabled(false);
+    
     enableButton(Ok, false);
     enableButton(User1, false);
     m_parent->setCursor( KCursor::waitCursor() );
@@ -430,7 +424,6 @@ void DespeckleDialog::despeckle(uint* data, int w, int h, int despeckle_radius,
      // Setup for filter...
 
      image.create( w, h, 32 );
-     image.setAlphaBuffer(true) ;
      memcpy(image.bits(), data, image.numBytes());
 
      size        = despeckle_radius * 2 + 1;
