@@ -8,7 +8,7 @@
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
- * Public License as published bythe Free Software Foundation;
+ * Public License as published by the Free Software Foundation;
  * either version 2, or (at your option)
  * any later version.
  * 
@@ -24,7 +24,7 @@
 
 // Digikam includes.
 
-#include <digikam/imageplugin.h>
+#include <digikamheaders.h>
 
 class ImagePlugin_Unsharp : public Digikam::ImagePlugin
 {
@@ -36,8 +36,6 @@ public:
                         const QStringList &args);
     ~ImagePlugin_Unsharp();
 
-    QStringList guiDefinition() const;
-
 private slots:
 
     void slotUnsharp();
