@@ -12,7 +12,7 @@
  * 
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
- * Public License as published bythe Free Software Foundation;
+ * Public License as published by the Free Software Foundation;
  * either version 2, or (at your option)
  * any later version.
  * 
@@ -23,12 +23,6 @@
  * 
  * ============================================================ */
 
-
-// Imlib2 include.
-
-#define X_DISPLAY_MISSING 1
-#include <Imlib2.h>
-
 // C++ include.
 
 #include <cstring>
@@ -60,15 +54,13 @@
 #include <kiconloader.h>
 #include <kapplication.h>
 #include <kpopupmenu.h>
-#include <kimageeffect.h>
 #include <kprogress.h>
 #include <kdebug.h>
 #include <kstandarddirs.h>
 
 // Digikam includes.
 
-#include <digikam/imageiface.h>
-#include <digikam/imagepreviewwidget.h>
+#include <digikamheaders.h>
 
 // Local includes.
 
@@ -79,9 +71,9 @@ namespace DigikamUnsharpFilterImagesPlugin
 {
 
 UnsharpDialog::UnsharpDialog(QWidget* parent)
-               : KDialogBase(Plain, i18n("Unsharped Mask"), Help|User1|Ok|Cancel, Ok,
-                             parent, 0, true, true, i18n("&Reset Values")),
-                 m_parent(parent)
+             : KDialogBase(Plain, i18n("Unsharped Mask"), Help|User1|Ok|Cancel, Ok,
+                           parent, 0, true, true, i18n("&Reset Values")),
+               m_parent(parent)
 {
     QString whatsThis;
     
@@ -93,11 +85,11 @@ UnsharpDialog::UnsharpDialog(QWidget* parent)
     KAboutData* about = new KAboutData("digikamimageplugins",
                                        I18N_NOOP("Unsharped Mask"), 
                                        digikamimageplugins_version,
-                                       I18N_NOOP("An unsharped mask image filter plugin for Digikam."),
+                                       I18N_NOOP("An unsharped mask image filter plugin for digiKam."),
                                        KAboutData::License_GPL,
                                        "(c) 2004, Gilles Caulier", 
                                        0,
-                                       "http://extragear.kde.org/apps/digikamimageplugins.php");
+                                       "http://extragear.kde.org/apps/digikamimageplugins");
     
     about->addAuthor("Gilles Caulier", I18N_NOOP("Author and maintainer"),
                      "caulier dot gilles at free.fr");
@@ -131,7 +123,8 @@ UnsharpDialog::UnsharpDialog(QWidget* parent)
     QString directory;
     KGlobal::dirs()->addResourceType("digikamimageplugins_banner_left", KGlobal::dirs()->kde_default("data") +
                                                                         "digikamimageplugins/data");
-    directory = KGlobal::dirs()->findResourceDir("digikamimageplugins_banner_left", "digikamimageplugins_banner_left.png");
+    directory = KGlobal::dirs()->findResourceDir("digikamimageplugins_banner_left",
+                                                 "digikamimageplugins_banner_left.png");
     
     pixmapLabelLeft->setPaletteBackgroundColor( QColor(201, 208, 255) );
     pixmapLabelLeft->setPixmap( QPixmap( directory + "digikamimageplugins_banner_left.png" ) );
@@ -142,7 +135,7 @@ UnsharpDialog::UnsharpDialog(QWidget* parent)
     QHBoxLayout *hlay1 = new QHBoxLayout(topLayout);
     
     m_imagePreviewWidget = new Digikam::ImagePreviewWidget(240, 160, 
-                                                           i18n("Unsharped Mask Image Preview"),
+                                                           i18n("Preview"),
                                                            plainPage());
     hlay1->addWidget(m_imagePreviewWidget);
     
@@ -157,7 +150,8 @@ UnsharpDialog::UnsharpDialog(QWidget* parent)
     m_radiusSlider->setTracking ( false );
     
     m_radiusInput = new QSpinBox(1, 1200, 1, plainPage(), "m_radiusInput");
-
+    m_radiusInput->setValue(50);
+    
     whatsThis = i18n("<p>A radius of 0 has no effect, "
                      "10 and above determine the blur matrix radius "
                      "that determines how much to blur the image.");
@@ -180,7 +174,8 @@ UnsharpDialog::UnsharpDialog(QWidget* parent)
     m_amountSlider->setTracking ( false );
     
     m_amountInput = new QSpinBox(0, 50, 1, plainPage(), "m_amountInput");
-        
+    m_amountInput->setValue(5);
+            
     whatsThis = i18n("<p>The value of the difference between the "
                      "original and the blur image that is added back "      
                      "into the original.");
@@ -203,7 +198,8 @@ UnsharpDialog::UnsharpDialog(QWidget* parent)
     m_thresholdSlider->setTracking ( false );  
     
     m_thresholdInput = new QSpinBox(0, 255, 1, plainPage(), "m_thresholdInput");
-    
+    m_thresholdInput->setValue(0);
+        
     whatsThis = i18n("<p>The threshold, as a fraction of the maximum luminosity value, "
                      "needed to apply the difference amount.");
     
@@ -222,6 +218,9 @@ UnsharpDialog::UnsharpDialog(QWidget* parent)
     QWhatsThis::add( m_progressBar, i18n("<p>This is the current percentage of the task completed.") );
     hlay5->addWidget(m_progressBar, 1);
     
+    adjustSize();
+    disableResize();  
+        
     // -------------------------------------------------------------
         
     connect(m_imagePreviewWidget, SIGNAL(signalOriginalClipFocusChanged()),
@@ -247,12 +246,6 @@ UnsharpDialog::UnsharpDialog(QWidget* parent)
             m_thresholdSlider, SLOT(setValue(int)));
     connect(m_thresholdInput, SIGNAL(valueChanged (int)),
             this, SLOT(slotEffect()));                                                
-    
-    // -------------------------------------------------------------
-        
-    adjustSize();
-    disableResize();          
-    QTimer::singleShot(0, this, SLOT(slotUser1()));    // Reset all parameters to the default values.    
 }
 
 UnsharpDialog::~UnsharpDialog()
@@ -279,32 +272,26 @@ void UnsharpDialog::slotCancel()
 
 void UnsharpDialog::slotUser1()
 {
-    blockSignals(true);
-    disconnect(m_imagePreviewWidget, SIGNAL(signalOriginalClipFocusChanged()),
-               this, SLOT(slotEffect()));    
-    disconnect(m_radiusInput, SIGNAL(valueChanged (int)),
-               this, SLOT(slotEffect()));  
-    disconnect(m_amountInput, SIGNAL(valueChanged (int)),
-               this, SLOT(slotEffect())); 
-    disconnect(m_thresholdInput, SIGNAL(valueChanged (int)),
-               this, SLOT(slotEffect()));                                                
-                           
+    m_radiusInput->blockSignals(true);
+    m_radiusSlider->blockSignals(true);
+    m_amountInput->blockSignals(true);
+    m_amountSlider->blockSignals(true);
+    m_thresholdInput->blockSignals(true);
+    m_thresholdSlider->blockSignals(true);
+                
     m_radiusInput->setValue(50);
     m_radiusSlider->setValue(50);
     m_amountInput->setValue(5);
     m_amountSlider->setValue(5);
     m_thresholdInput->setValue(0);
     m_thresholdSlider->setValue(0);
-    
-    connect(m_imagePreviewWidget, SIGNAL(signalOriginalClipFocusChanged()),
-            this, SLOT(slotEffect()));
-    connect(m_radiusInput, SIGNAL(valueChanged (int)),
-            this, SLOT(slotEffect()));  
-    connect(m_amountInput, SIGNAL(valueChanged (int)),
-            this, SLOT(slotEffect()));             
-    connect(m_thresholdInput, SIGNAL(valueChanged (int)),
-            this, SLOT(slotEffect()));                                                
-    blockSignals(false);
+                                     
+    m_radiusInput->blockSignals(false);
+    m_radiusSlider->blockSignals(false);
+    m_amountInput->blockSignals(false);
+    m_amountSlider->blockSignals(false);
+    m_thresholdInput->blockSignals(false);
+    m_thresholdSlider->blockSignals(false);
     slotEffect();
 } 
 
@@ -332,6 +319,14 @@ void UnsharpDialog::slotEffect()
 
 void UnsharpDialog::slotOk()
 {
+    m_radiusInput->setEnabled(false);
+    m_radiusSlider->setEnabled(false);
+    m_amountInput->setEnabled(false);
+    m_amountSlider->setEnabled(false);
+    m_thresholdInput->setEnabled(false);
+    m_thresholdSlider->setEnabled(false);
+    m_imagePreviewWidget->setEnabled(false);
+    
     enableButton(Ok, false);
     enableButton(User1, false);
     m_parent->setCursor( KCursor::waitCursor() );
